bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 27. Aventiure
___________________________________________________ #### Aventivre wie der marchrave die kvnige mit ir rechen #### in sin hvs enpfie vnd wier ir sit pflach
###### 1650 | ### Do gie der margrave | da er di vrovn vant ### sin wip mit siner tohter | vnt sagete in zehant ### div vil lieben maere | div er het vernomen ### daz in ir frovn brvder | dar ce hvse solden chomen
###### 1651 | ### vil liebiv trvettinne | sprach do rvedger ### ir svlt vil wol enpfahen | di edelen chvenige her ### so si mit ir gesinde | her ce hove gan ### ir svlt ovch schone grvezen | hagen gventheres man
###### 1652 | ### mit in chvmt ovch einer | der heizet danchwart ### der ander heizet volker | an zvehten wol bewart ### di sehse svlt ir chvessen | vnt div tohter min ### vnde svlt ovch bi den recken | in zvehten gvetliche sin
###### 1653 | ### daz lobten do di vrowen | vnd warn sin bereit ### si svchten vz den chisten | div herlichen chleit ### darinne si engegene | den recken wolden gan ### da wart vil michel vlizen | von schoenen wiben getan
###### 1654 | ### gevelshet frovn varwe | vil lvecel man da vant ### si trvgen vf ir hovbete | von golde liehtiv bant ### daz waren shapel riche | daz in ir schoene har ### cefvrten niht di winde | daz ist an den triwen war
###### 1655 | ### in solhen vnmvzen | svl wir di vrowen lan ### hi wart vil michel gahen | veber velt getan ### von rvedgeres vrivnden | da man di fversten vant ### si wurden wol enpfangen | in des margraven lant
###### 1656 | ### do si der margrave | zv zim chomen sach ### rvedger der snelle | vil vroeliche sprach ### sit willechomen ir herren | vnd ovch iwer man ### hie in minem lande | vil gern ich ivh gesehen han
###### 1657 | ### do nigen im di recken | mit triwen ane haz ### daz er in willech waere | vil wol erzeigete er daz ### besvnder grvzte er hagenen | den het er e bechant ### alsam tet er volkern | vzer bvrgonden lant
###### 1658 | ### er enpfie ovch danchwarten | do sprach der chvene degen ### sit ir vns wilt bervchen | nv wer sol danne pflegen ### des vnsern ingesindes | daz wir haben braht ### do sprach der margrave | ir svlt haben gvte naht
###### 1659 | ### vnd allez iwer gesinde | swaz ir in daz lant ### habt mit iv gefveret ross | vnd ovch gewant ### dem shaffe ich soelhe hvte | daz sin niht verlorn ### daz iv ce shaden bringe | gegen enigem sporn
###### 1660 | ### spannet vf ir knehte | di hvetten an daz velt ### swaz ir hie verlieset | des wil ich wesen gelt ### ziehet ab di zovme | div ross lazet gan ### daz het in wirt deheiner | davor vil selten getan
###### 1661 | ### des vroevten sich di geste | do daz geshaffen was ### di herren riten dannen | sich leiten an daz gras ### vber al di knehte | si heten gvt gemach ### ich waene in an dirre verte | ni so sanfte geshach
###### 1662 | ### div edele margravinne | was di fver di bvrch gegan ### mit ir vil schoenen tohter | do sah man bi ir stan ### di minnechlichen vrowen | vnd manige shoen meit ### di trvgen vil der bovge | vnd ovch herlichiv chleit
###### 1663 | ### daz edel gesteine | lvhte verre dan ### vz ir vil richen waete | si waren wolgetan ### do chomen ovch di geste | vnd erbeizten sa cehant ### hey waz man grozer zvehte | an den bvrgonden vant
###### 1664 | ### sehs vnt drizech maegde | vnt manich ander wip ### den was wol ce wunshe | geshaffen gar der lip ### di giengen in engegene | mit manigem chvenem man ### da wart ein shoene grvezen | von edeln vrowen getan
###### 1665 | ### div edele margravinne | chvste di kvenige alle dri ### alsam tet ir mvter | da stvnt ovch hagen bi ### ir vater hiez in chvessen | do blichte si in an ### er dvhte si so vorhtlich | daz siz vil gerne hete lan
###### 1666 | ### do mvste si daz leisten | daz ir der wirt gebot ### gemisschet wart ir varwe | bleich vnde rot ### si chvste ovch danchwarten | darnach den spileman ### dvrch sines libes ellen | wart im daz grvzen getan
###### 1667 | ### div ivnge margravinne | div nam bi der hant ### giselher den recken | von bvrgonden lant ### alsam tet ovch ir mvter | gventher der chvenen man ### si giengen mit den helden | vil harte vroliche dan
###### 1668 | ### der wirt gi bi gernote | in einen witen sal ### ritter vnd vrowen | gesazen da ce tal ### do hiez man balde shenchen | den gesten gvten win ### ia ne dorften nimmer helde | baz gehandelet sin
###### 1669 | ### mit lieben ovgenblicken | wart gesehen an ### div rvedgeres tohter | div was so wolgetan ### ia trvtes in den sinnen | vil manich ritter gvt ### daz chonde ovch si verdienen | si was hohe gemvt
###### 1670 | ### si dahten swes si wolden | des en mohte aver niht geshehen ### hin vnd her wider | wart da vil gesehen ### an mageden vnd an vrowen | der saz da genvch ### der edel videlaere | dem wirte holden willen trvch
###### 1671 | ### nach gewonheite | so schieden si sich da ### ritter vnd vrowen | di giengen anderswa ### do rihte man di tisshe | in dem sale wit ### den vnchvnden gesten | diente man herliche sit
###### 1672 | ### dvrch der geste liebe | hin ce tisshe gie ### div edele margravinne | ir tohter si do lie ### beliben bi den chinden | da si von rehte saz ### di geste ir niht en sahen | si mvte waerliche daz
###### 1673 | ### do si getrvnchen heten | vnd gezen veber al ### do wiste man di schoenen | wider in den sal ### gaemelicher sprveche | wart da niht verdeit ### der redete vil do volker | ein degen chven vnt gemeit
###### 1674 | ### do sprach offenlichen | der edel spilman ### richer margrave | got hat an iv getan ### vil genaedechlichen | wand er iv hat gegeben ### ein wip so rehte schoene | darzv ein wunnechlichez leben
###### 1675 | ### ob ich ein fverste waere | sprach der spilman ### vnd solde ich tragen chrone | ce wibe wold ich han ### di iwern schoenen tohter | des wuensshet mir der mvt ### div ist minnechlich ce sehen | darzv edel vnd gvt
###### 1676 | ### do sprach der margrave | wi moehte daz gesin ### daz immer kvenech gerte | der lieben tohter min ### wir sin hi ellende | beide ich vnd min wip ### waz hilfet groziv schoene | an der ivnchvrowen lip
###### 1677 | ### des antwurte gernot | der wolgezogen man ### vnd sold ich trivttinne | nach minem willen han ### so wold ich solhes wibes | immer wesen vro ### des antwurte hagene | vil harte gvetlichen do
###### 1678 | ### nv sol min herre giselher | doch nemen ein wip ### ez ist so hoher mage | der margravinne lip ### daz wir gerne dienten | ich vnde sine man ### vnd soldes vnder chrone | da cen bvrgonden gan
###### 1679 | ### div rede rvedgeren | dvhte harte gvt ### vnd ovch gotelinde | ia frevte sich in der mvt ### do trvgen an di helde | daz si ce wibe nam ### giselher der edele | als ez wol chvenege gezam
###### 1680 | ### swaz sich sol gefvegen | wer moeht daz vndersten ### man bat di ivnchvrowen | hin ce hove gen ### do swuor man im ze gebene | daz wuennechliche wip ### do lobt ovch er ce minnen | den ir vil minnechlichen lip
###### 1681 | ### man beshiet der ivnchvrowen | bverge vnde lant ### des sicherte da mit eiden | des edeln chveniges hant ### vnde ovch der herre gernot | daz wurde daz getan ### do sprach der margrave | sit ich der bverge nine han
###### 1682 | ### so sol ich iv mit triwen | immer wesen holt ### ich gibe ce miner tohter | silber vnde golt ### so hvndert sovmaere | meiste mvegen tragen ### daz ich des heldes magen | nach eren mvege wol behagen
###### 1683 | ### do hiez man si beide | sten an einen rinch ### nach gewonheite | vil manich ivngelinch ### in vroelichem mvte | in cegegen stvnt ### si gedahten in ir sinnen | so noch di tvmmen gerne tvnt
###### 1684 | ### do man begonde vragen | di minnechlichen meit ### ob si den recken wolde | ein teil was ez ir leit ### vnt dahte doch ce nenemne | den waetlichen man ### si shamte sich der vrage | so manich magt hat getan
###### 1685 | ### ir riet ir vater rvedger | daz si spreche ia ### vnt daz si in gerne naeme | vil schiere do was da ### mit sinen wizen handen | der si vmbesloz ### giselher der edele | swi lvecel si sin doch genoz
###### 1686 | ### do sprach der margrave | ir edele chvenege rich ### als ir nv wider ritet | daz ist gewonlich ### heim hin zen bvrgonden | so gip ich iv min chint ### daz ir si mit iv fveret | daz gelobten si sint
###### 1687 | ### swaz man do shalles horte | den mvsen si do lan ### man hiez di ivnchvrowen | cer kemnaten gan ### vnd ovch di geste slaffen | vnd ruwen an den tach ### do bereite man di spise | der wirt ir gvetliche pflach
###### 1688 | ### do si enbizzen waren | si wolden dannen varn ### gegen der hivnen landen | daz heiz ich wol bewarn ### sprach der wirt vil edele | ir svlt ovch hi bestan ### wand ich so lieber geste | selten hie iht gewunnen han
###### 1689 | ### des antwurte danchwart | ia ne mag es niht gesin ### wa nemt ir di spise | daz brot vnd ovch den win ### daz ir so manigen recken | noch hinte mveset han ### do daz der wirt gehorte | er sprach ir svlt di rede lan
###### 1690 | ### mine vil lieben herren | ir svlt mir niht versagen ### ia gebe ich iv di spise | ce vierzehen tagen ### mit allem iwerem gesinde | daz mit iv her ist chomen ### mir hat der kvenech ecel | noch vil wenich iht genomen
###### 1691 | ### swi sere si sich werten | si mvsen da bestan ### vnz an den vierden morgen | do wart da getan ### von des wirtes milte | daz verre wart geseit ### er gap den sinen gesten | beidiv ross vnd chleit
###### 1692 | ### ez en chvnde niht wern langer | si mvsen dannen varn ### rvedger der chvene | vil wenich iht gesparn ### chond vor siner milte | swes iemen gerte nemen ### daz versagete er niemen | ez mvse in allen gezemen
###### 1693 | ### ir edel ingesinde | brahte fver daz tor ### gesatelt vil der moere | do chom zv zin davor ### vil der vremden recken | si trvgen schilde enhant ### wande si wolden ritten | in daz eceln lant
###### 1694 | ### der wirt do sine gabe | bot veber al ### e daz di edeln geste | choemen fvr den sal ### er chonde miltechliche | mit grozen eren leben ### die sine tohter shoene | di het er giselher gegeben
###### 1695 | ### do gap er gvnthere | dem helde lobelich ### daz wol trvch mit eren | der edel fvrste rich ### swi selten er gabe enpfienge | ein wafenlich gewant ### darnah neich do gventher | des edeln rvedgeres hant
###### 1696 | ### do gap er gernote | ein waffen gvt genvch ### daz er sit in stvrme | vil herlichen trvch ### der gabe im vil wol gonde | des margraven wip ### davon der gvte rvedger | sit mvse vliesen den lip
###### 1697 | ### gotelint bot hagenen | als ir vil wol gezam ### ir minnechlichen gabe | sit si der kvnech nam ### daz er ovh an ir stivre | zv der hohgecit ### von ir varn niht solde | doh widerredete er iz sit
###### 1698 | ### alles des ich ie gesach | sprach do hagene ### so ne gert ich niht mere | hinnen ce tragene ### niwan ienes shildes | dort an iener want ### den wolde ich gerne fveren | in daz eceln lant
###### 1699 | ### do div margravinne | hagen rede vernam ### ez mante si ir leides | weinen si gezam ### do gedahte si vil tivre | an nvodvnges tot ### den het erslagen witege | davon so het si iamers not
###### 1700 | ### si sprach zv dem degene | den schilt wil ich iv geben ### daz wolde got von himele | daz er noch solde leben ### der in da trvch enhende | der lag in stvrme tot ### den mvoz ich imer weinen | des gat mir armem wibe not
###### 1701 | ### div edele margravinne | von dem sedele gie ### mit ir vil wizen handen | si den schilt gevie ### div vrowe trvg in hagenen | er nam in an di hant ### div gabe was mit eren | an den recken gewant
###### 1702 | ### ein hvlft von liehtem pfelle | ob siner varwe lach ### bezzern shilt deheinen | belvhte ni der tach ### von edelm gesteine | swer sin hete gegert ### ce chovffen an der choste | was er wol tvsent marche wert
###### 1703 | ### den schilt hiez do hagene | tragen vor im dan ### do begonde danchwart | hin ce hove gan ### dem gap vil richiv kleider | des margraven chint ### div trvch er cen hivnen | vil harte herliche sint
###### 1704 | ### allez daz der gabe | von in wart genomen ### in ir deheines hende | waer ir niht bechomen ### wan dvrh des wirtes liebe | derz in so schone bot ### sit wurdens im so vient | daz si in mvsen slahen tot
###### 1705 | ### volker der snelle | mit siner videlen dan ### gie gezogenliche | fver gotelinde stan ### er videlte sveze doene | vnd sanch ir siniv liet ### damit nam er vrlovp | do er von bechelarn schiet
###### 1706 | ### ir hiez div margravinne | eine lade tragen ### von frivntlicher gabe | mveget ir horen sagen ### darvz nam si zwelf povge | vnde spiens im an di hant ### di svlt ir hinnen fveren | in daz eceln lant
###### 1707 | ### vnde svlt dvrh minen willen | si ce hove tragen ### swenne ir wider wendet | daz man mir mvege sagen ### wi ir mir habt gedienet | da cer hohgecit ### des div vrowe gerte | vil wol leist er daz sit
###### 1708 | ### do sprach der wirt cen gesten | ir svlt deste sanfter varn ### ich wil ivch selbe leiten | vnd heizen wol bewarn ### daz iv vf der straze | niemen mvge geschaden ### do wurden sine sovme | harte schiere geladen
###### 1709 | ### der wirt wart wol bereitet | mit fvnfhvndert man ### mit rossen vnd mit chleidern | di fvrt er mit im dan ### vil harte herlichen | zv der hohgezit ### der einer mit dem lebene | chom ni ze bechelaren sit
###### 1710 | ### mit chvsse minnechliche | der wirt do dannen schiet ### also reit ovch giselher | als im sin tvgent riet ### mit vmbslozen armen | si trvten schoniv wip ### daz mvse sit beweinen | vil maniger ivnchvrowen lip
###### 1711 | ### do wurden allenthalben | div venster vf getan ### der wirt mit sinen mannen | cen rossen wolde gan ### ich waen ir herce in sagete | div crefftechlichen leit ### da weinte manich vrowe | vnd manich waetlichiv meit
###### 1712 | ### nach ir lieben frivnden | genvge heten ser ### di si ce bechelaren | gesahen nimmer mer ### doch riten si mit vrevden | nider vber sant ### ce tal bi tvnowe | vz in daz hivnisshe lant
###### 1713 | ### do sprach cen bvrgonden | der ritter vil gemeit ### rvedger der edele | ian svln niht verdeit ### wesen vnser maere | daz wir zen hivnen chomen ### im hat der kvenich ecel | ni so libes niht vernomen
###### 1714 | ### ze tal dvrch osterriche | der bote balde reit ### den livten allenthalben | wart daz wol geseit ### daz di helde chomen | von wormez veber rin ### des kveneges ingesinde | chonde ez niht lieber gesin
###### 1715 | ### di boten fver strichen | mit den maeren ### daz di nibelvnge | zen hivnen waeren ### dv solt si wol enpfahen | criemhilt vrowe min ### dir choment nach vil grozen eren | di vil lieben brvder din
###### 1716 | ### criemhilt div vrowe | in ein venster stvnt ### si warte nach den magen | so noch frivnde nach frivnden tvnt ### von ir vaterlande | sach si manigen man ### der kvenich vriehs ovch div maere | vor liebe er lachen began
###### 1717 | ### nv wol mich miner vrevden | sprach do criemhilt ### hi bringent mine mage | vil manigen niwen schilt ### von halsperge wiz | swer nemen welle golt ### der gedenche miner leide | vnd wil im immer wesen holt

<<< Übersicht <<< vorige Seite nächste Seite >>>